@@ -169,6 +169,19 @@ class IPDFPage(IRMLTemplated, IPageBase):
         required=False
         )
 
+    render_invariant = zope.schema.Bool(
+        title=u"Render invariant",
+        description=u"Render without influence form environment, like current time.",
+        required=False)
+
+    render_debug = zope.schema.Bool(
+        title=u"Render debug",
+        description=u"Render with debug information.",
+        required=False)
+
+    inline = zope.schema.Bool(
+        title=u"Render inline", required=False)
+
     content_template = Attribute(
         u"Template that renders the main content.")
 
